// Automatically generated file. DO NOT EDIT.
// Generated by gen-device-svd.go from stm32h523.svd, see https://github.com/tinygo-org/stm32-svd

/*
// STM32H523
*/



.syntax unified

// This is the default handler for interrupts, if triggered but not defined.
.section .text.Default_Handler
.global  Default_Handler
.type    Default_Handler, %function
Default_Handler:
    wfe
    b    Default_Handler
.size Default_Handler, .-Default_Handler

// Avoid the need for repeated .weak and .set instructions.
.macro IRQ handler
    .weak  \handler
    .set   \handler, Default_Handler
.endm

// Must set the "a" flag on the section:
// https://svnweb.freebsd.org/base/stable/11/sys/arm/arm/locore-v4.S?r1=321049&r2=321048&pathrev=321049
// https://sourceware.org/binutils/docs/as/Section.html#ELF-Version
.section .isr_vector, "a", %progbits
.global  __isr_vector
__isr_vector:
    // Interrupt vector as defined by Cortex-M, starting with the stack top.
    // On reset, SP is initialized with *0x0 and PC is loaded with *0x4, loading
    // _stack_top and Reset_Handler.
    .long _stack_top
    .long Reset_Handler
    .long NMI_Handler
    .long HardFault_Handler
    .long MemoryManagement_Handler
    .long BusFault_Handler
    .long UsageFault_Handler
    .long 0
    .long 0
    .long 0
    .long 0
    .long SVC_Handler
    .long DebugMon_Handler
    .long 0
    .long PendSV_Handler
    .long SysTick_Handler

    // Extra interrupts for peripherals defined by the hardware vendor.
    .long WWDG_IRQHandler
    .long 0
    .long RTC_IRQHandler
    .long RTC_S_IRQHandler
    .long TAMP_IRQHandler
    .long RAMCFG_IRQHandler
    .long FLASH_IRQHandler
    .long FLASH_S_IRQHandler
    .long GTZC_IRQHandler
    .long RCC_IRQHandler
    .long RCC_S_IRQHandler
    .long EXTI0_IRQHandler
    .long EXTI1_IRQHandler
    .long EXTI2_IRQHandler
    .long EXTI3_IRQHandler
    .long EXTI4_IRQHandler
    .long EXTI5_IRQHandler
    .long EXTI6_IRQHandler
    .long EXTI7_IRQHandler
    .long EXTI8_IRQHandler
    .long EXTI9_IRQHandler
    .long EXTI10_IRQHandler
    .long EXTI11_IRQHandler
    .long EXTI12_IRQHandler
    .long EXTI13_IRQHandler
    .long EXTI14_IRQHandler
    .long EXTI15_IRQHandler
    .long GPDMA1_CH0_IRQHandler
    .long GPDMA1_CH1_IRQHandler
    .long GPDMA1_CH2_IRQHandler
    .long GPDMA1_CH3_IRQHandler
    .long GPDMA1_CH4_IRQHandler
    .long GPDMA1_CH5_IRQHandler
    .long GPDMA1_CH6_IRQHandler
    .long GPDMA1_CH7_IRQHandler
    .long IWDG_IRQHandler
    .long 0
    .long ADC1_IRQHandler
    .long DAC1_IRQHandler
    .long FDCAN1_IT0_IRQHandler
    .long FDCAN1_IT1_IRQHandler
    .long TIM1_BRK_TERR_IERR_IRQHandler
    .long TIM1_UPD_IRQHandler
    .long TIM1_TRGI_COM_DIR_IDX_IRQHandler
    .long TIM1_CC_IRQHandler
    .long TIM2_IRQHandler
    .long TIM3_IRQHandler
    .long TIM4_IRQHandler
    .long TIM5_IRQHandler
    .long TIM6_IRQHandler
    .long TIM7_IRQHandler
    .long I2C1_EV_IRQHandler
    .long I2C1_ERR_IRQHandler
    .long I2C2_EV_IRQHandler
    .long I2C2_ERR_IRQHandler
    .long SPI1_IRQHandler
    .long SPI2_IRQHandler
    .long SPI3_IRQHandler
    .long USART1_IRQHandler
    .long USART2_IRQHandler
    .long USART3_IRQHandler
    .long UART4_IRQHandler
    .long UART5_IRQHandler
    .long LPUART1_IRQHandler
    .long LPTIM1_IRQHandler
    .long TIM8_BRK_TERR_IERR_IRQHandler
    .long TIM8_UPD_IRQHandler
    .long TIM8_TRGI_DIR_IDX_IRQHandler
    .long TIM8_CC_IRQHandler
    .long ADC2_IRQHandler
    .long LPTIM2_IRQHandler
    .long TIM15_IRQHandler
    .long 0
    .long 0
    .long USB_FS_IRQHandler
    .long CRS_IRQHandler
    .long UCPD1_IRQHandler
    .long FMC_IRQHandler
    .long OCTOSPI1_IRQHandler
    .long SDMMC1_IRQHandler
    .long I2C3_EV_IRQHandler
    .long I2C3_ERR_IRQHandler
    .long SPI4_IRQHandler
    .long 0
    .long 0
    .long USART6_IRQHandler
    .long 0
    .long 0
    .long 0
    .long 0
    .long GPDMA2_CH0_IRQHandler
    .long GPDMA2_CH1_IRQHandler
    .long GPDMA2_CH2_IRQHandler
    .long GPDMA2_CH3_IRQHandler
    .long GPDMA2_CH4_IRQHandler
    .long GPDMA2_CH5_IRQHandler
    .long GPDMA2_CH6_IRQHandler
    .long GPDMA2_CH7_IRQHandler
    .long 0
    .long 0
    .long 0
    .long 0
    .long 0
    .long FPU_IRQHandler
    .long ICACHE_IRQHandler
    .long DCACHE_IRQHandler
    .long 0
    .long 0
    .long DCMI_PSSI_IRQHandler
    .long FDCAN2_IT0_IRQHandler
    .long FDCAN2_IT1_IRQHandler
    .long 0
    .long 0
    .long DTS_OR_DTS_WKUP_IRQHandler
    .long RNG_IRQHandler
    .long 0
    .long 0
    .long HASH_IRQHandler
    .long 0
    .long CEC_IRQHandler
    .long 0
    .long 0
    .long 0
    .long I3C1_EV_IRQHandler
    .long I3C1_ERR_IRQHandler
    .long 0
    .long 0
    .long 0
    .long 0
    .long 0
    .long 0
    .long I3C2_EV_IRQHandler
    .long I3C2_ERR_IRQHandler

    // Define default implementations for interrupts, redirecting to
    // Default_Handler when not implemented.
    IRQ NMI_Handler
    IRQ HardFault_Handler
    IRQ MemoryManagement_Handler
    IRQ BusFault_Handler
    IRQ UsageFault_Handler
    IRQ SVC_Handler
    IRQ DebugMon_Handler
    IRQ PendSV_Handler
    IRQ SysTick_Handler
    IRQ WWDG_IRQHandler
    IRQ RTC_IRQHandler
    IRQ RTC_S_IRQHandler
    IRQ TAMP_IRQHandler
    IRQ RAMCFG_IRQHandler
    IRQ FLASH_IRQHandler
    IRQ FLASH_S_IRQHandler
    IRQ GTZC_IRQHandler
    IRQ RCC_IRQHandler
    IRQ RCC_S_IRQHandler
    IRQ EXTI0_IRQHandler
    IRQ EXTI1_IRQHandler
    IRQ EXTI2_IRQHandler
    IRQ EXTI3_IRQHandler
    IRQ EXTI4_IRQHandler
    IRQ EXTI5_IRQHandler
    IRQ EXTI6_IRQHandler
    IRQ EXTI7_IRQHandler
    IRQ EXTI8_IRQHandler
    IRQ EXTI9_IRQHandler
    IRQ EXTI10_IRQHandler
    IRQ EXTI11_IRQHandler
    IRQ EXTI12_IRQHandler
    IRQ EXTI13_IRQHandler
    IRQ EXTI14_IRQHandler
    IRQ EXTI15_IRQHandler
    IRQ GPDMA1_CH0_IRQHandler
    IRQ GPDMA1_CH1_IRQHandler
    IRQ GPDMA1_CH2_IRQHandler
    IRQ GPDMA1_CH3_IRQHandler
    IRQ GPDMA1_CH4_IRQHandler
    IRQ GPDMA1_CH5_IRQHandler
    IRQ GPDMA1_CH6_IRQHandler
    IRQ GPDMA1_CH7_IRQHandler
    IRQ IWDG_IRQHandler
    IRQ ADC1_IRQHandler
    IRQ DAC1_IRQHandler
    IRQ FDCAN1_IT0_IRQHandler
    IRQ FDCAN1_IT1_IRQHandler
    IRQ TIM1_BRK_TERR_IERR_IRQHandler
    IRQ TIM1_UPD_IRQHandler
    IRQ TIM1_TRGI_COM_DIR_IDX_IRQHandler
    IRQ TIM1_CC_IRQHandler
    IRQ TIM2_IRQHandler
    IRQ TIM3_IRQHandler
    IRQ TIM4_IRQHandler
    IRQ TIM5_IRQHandler
    IRQ TIM6_IRQHandler
    IRQ TIM7_IRQHandler
    IRQ I2C1_EV_IRQHandler
    IRQ I2C1_ERR_IRQHandler
    IRQ I2C2_EV_IRQHandler
    IRQ I2C2_ERR_IRQHandler
    IRQ SPI1_IRQHandler
    IRQ SPI2_IRQHandler
    IRQ SPI3_IRQHandler
    IRQ USART1_IRQHandler
    IRQ USART2_IRQHandler
    IRQ USART3_IRQHandler
    IRQ UART4_IRQHandler
    IRQ UART5_IRQHandler
    IRQ LPUART1_IRQHandler
    IRQ LPTIM1_IRQHandler
    IRQ TIM8_BRK_TERR_IERR_IRQHandler
    IRQ TIM8_UPD_IRQHandler
    IRQ TIM8_TRGI_DIR_IDX_IRQHandler
    IRQ TIM8_CC_IRQHandler
    IRQ ADC2_IRQHandler
    IRQ LPTIM2_IRQHandler
    IRQ TIM15_IRQHandler
    IRQ USB_FS_IRQHandler
    IRQ CRS_IRQHandler
    IRQ UCPD1_IRQHandler
    IRQ FMC_IRQHandler
    IRQ OCTOSPI1_IRQHandler
    IRQ SDMMC1_IRQHandler
    IRQ I2C3_EV_IRQHandler
    IRQ I2C3_ERR_IRQHandler
    IRQ SPI4_IRQHandler
    IRQ USART6_IRQHandler
    IRQ GPDMA2_CH0_IRQHandler
    IRQ GPDMA2_CH1_IRQHandler
    IRQ GPDMA2_CH2_IRQHandler
    IRQ GPDMA2_CH3_IRQHandler
    IRQ GPDMA2_CH4_IRQHandler
    IRQ GPDMA2_CH5_IRQHandler
    IRQ GPDMA2_CH6_IRQHandler
    IRQ GPDMA2_CH7_IRQHandler
    IRQ FPU_IRQHandler
    IRQ ICACHE_IRQHandler
    IRQ DCACHE_IRQHandler
    IRQ DCMI_PSSI_IRQHandler
    IRQ FDCAN2_IT0_IRQHandler
    IRQ FDCAN2_IT1_IRQHandler
    IRQ DTS_OR_DTS_WKUP_IRQHandler
    IRQ RNG_IRQHandler
    IRQ HASH_IRQHandler
    IRQ CEC_IRQHandler
    IRQ I3C1_EV_IRQHandler
    IRQ I3C1_ERR_IRQHandler
    IRQ I3C2_EV_IRQHandler
    IRQ I3C2_ERR_IRQHandler

.size __isr_vector, .-__isr_vector
