; Automatically generated file. DO NOT EDIT.
; Generated by gen-device-avr.go from ATtiny416.atdf, see http://packs.download.atmel.com/

; This is the default handler for interrupts, if triggered but not defined.
; Sleep inside so that an accidentally triggered interrupt won't drain the
; battery of a battery-powered device.
.section .text.__vector_default
.global  __vector_default
__vector_default:
    sleep
    rjmp __vector_default

; Avoid the need for repeated .weak and .set instructions.
.macro IRQ handler
    .weak  \handler
    .set   \handler, __vector_default
.endm

; The interrupt vector of this device. Must be placed at address 0 by the linker.
.section .vectors, "a", %progbits
.global  __vectors
    rjmp __vector_RESET
    rjmp __vector_CRCSCAN_NMI
    rjmp __vector_BOD_VLM
    rjmp __vector_PORTA_PORT
    rjmp __vector_PORTB_PORT
    rjmp __vector_PORTC_PORT
    rjmp __vector_RTC_CNT
    rjmp __vector_RTC_PIT
    rjmp __vector_TCA0_LUNF
    rjmp __vector_TCA0_HUNF
    rjmp __vector_TCA0_LCMP0
    rjmp __vector_TCA0_CMP1
    rjmp __vector_TCA0_CMP2
    rjmp __vector_TCB0_INT
    rjmp __vector_TCD0_OVF
    rjmp __vector_TCD0_TRIG
    rjmp __vector_AC0_AC
    rjmp __vector_ADC0_RESRDY
    rjmp __vector_ADC0_WCOMP
    rjmp __vector_TWI0_TWIS
    rjmp __vector_TWI0_TWIM
    rjmp __vector_SPI0_INT
    rjmp __vector_USART0_RXC
    rjmp __vector_USART0_DRE
    rjmp __vector_USART0_TXC
    rjmp __vector_NVMCTRL_EE

    ; Define default implementations for interrupts, redirecting to
    ; __vector_default when not implemented.
    IRQ __vector_RESET
    IRQ __vector_CRCSCAN_NMI
    IRQ __vector_BOD_VLM
    IRQ __vector_PORTA_PORT
    IRQ __vector_PORTB_PORT
    IRQ __vector_PORTC_PORT
    IRQ __vector_RTC_CNT
    IRQ __vector_RTC_PIT
    IRQ __vector_TCA0_LUNF
    IRQ __vector_TCA0_OVF
    IRQ __vector_TCA0_HUNF
    IRQ __vector_TCA0_LCMP0
    IRQ __vector_TCA0_CMP0
    IRQ __vector_TCA0_CMP1
    IRQ __vector_TCA0_LCMP1
    IRQ __vector_TCA0_CMP2
    IRQ __vector_TCA0_LCMP2
    IRQ __vector_TCB0_INT
    IRQ __vector_TCD0_OVF
    IRQ __vector_TCD0_TRIG
    IRQ __vector_AC0_AC
    IRQ __vector_ADC0_RESRDY
    IRQ __vector_ADC0_WCOMP
    IRQ __vector_TWI0_TWIS
    IRQ __vector_TWI0_TWIM
    IRQ __vector_SPI0_INT
    IRQ __vector_USART0_RXC
    IRQ __vector_USART0_DRE
    IRQ __vector_USART0_TXC
    IRQ __vector_NVMCTRL_EE
