# This file is placed in the public domain.

# Note: this is both a Makefile and a shell script. It is included from both a
# Makefile and from a shell script to define version numbers in a central
# place. Therefore, this file should be kept compatible with both syntaxes.

# These are the values for macOS 11.5:
# https://opensource.apple.com/releases/
AvailabilityVersions_version=80.3
Libc_version=1439.141.1
libdispatch_version=1271.120.2
libmalloc_version=317.140.5
libplatform_version=254.80.2
libpthread_version=454.120.2
xnu_version=7195.141.2

# These are the values for Developer Tools 16.0:
# https://opensource.apple.com/releases/
cctools_version=1021.4

# These are not part of the lists above and don't seem to have any updates
# recently.
Libm_version=2026
