// Automatically generated file. DO NOT EDIT.
// Generated by gen-device-svd.go from R7FA4M3AF.svd, see https://github.com/cmsis-svd/cmsis-svd-data/tree/master/data/Renesas

/*
// Arm Cortex-M33 based Microcontroller RA4M3 group
*/

//     This software is supplied by Renesas Electronics Corporation and is only intended for
//     use with Renesas products. No other uses are authorized. This software is owned by
//     Renesas Electronics Corporation and is protected under all applicable laws, including
//     copyright laws.
//
//     THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING
//     THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO
//     WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT.
//     ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED. TO THE MAXIMUM EXTENT PERMITTED NOT
//     PROHIBITED BY LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED
//     COMPANIES SHALL BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL
//     DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS AFFILIATES HAVE
//     BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
//
//     Renesas reserves the right, without notice, to make changes to this software and to
//     discontinue the availability of this software. By using this software, you agree to
//     the additional terms and conditions found by accessing the following link:
//     http://www.renesas.com/disclaimer
//     \n

.syntax unified

// This is the default handler for interrupts, if triggered but not defined.
.section .text.Default_Handler
.global  Default_Handler
.type    Default_Handler, %function
Default_Handler:
    wfe
    b    Default_Handler
.size Default_Handler, .-Default_Handler

// Avoid the need for repeated .weak and .set instructions.
.macro IRQ handler
    .weak  \handler
    .set   \handler, Default_Handler
.endm

// Must set the "a" flag on the section:
// https://svnweb.freebsd.org/base/stable/11/sys/arm/arm/locore-v4.S?r1=321049&r2=321048&pathrev=321049
// https://sourceware.org/binutils/docs/as/Section.html#ELF-Version
.section .isr_vector, "a", %progbits
.global  __isr_vector
__isr_vector:
    // Interrupt vector as defined by Cortex-M, starting with the stack top.
    // On reset, SP is initialized with *0x0 and PC is loaded with *0x4, loading
    // _stack_top and Reset_Handler.
    .long _stack_top
    .long Reset_Handler
    .long NMI_Handler
    .long HardFault_Handler
    .long MemoryManagement_Handler
    .long BusFault_Handler
    .long UsageFault_Handler
    .long 0
    .long 0
    .long 0
    .long 0
    .long SVC_Handler
    .long DebugMon_Handler
    .long 0
    .long PendSV_Handler
    .long SysTick_Handler

    // Extra interrupts for peripherals defined by the hardware vendor.
    .long IEL0_IRQHandler
    .long IEL1_IRQHandler
    .long IEL2_IRQHandler
    .long IEL3_IRQHandler
    .long IEL4_IRQHandler
    .long IEL5_IRQHandler
    .long IEL6_IRQHandler
    .long IEL7_IRQHandler
    .long IEL8_IRQHandler
    .long IEL9_IRQHandler
    .long IEL10_IRQHandler
    .long IEL11_IRQHandler
    .long IEL12_IRQHandler
    .long IEL13_IRQHandler
    .long IEL14_IRQHandler
    .long IEL15_IRQHandler
    .long IEL16_IRQHandler
    .long IEL17_IRQHandler
    .long IEL18_IRQHandler
    .long IEL19_IRQHandler
    .long IEL20_IRQHandler
    .long IEL21_IRQHandler
    .long IEL22_IRQHandler
    .long IEL23_IRQHandler
    .long IEL24_IRQHandler
    .long IEL25_IRQHandler
    .long IEL26_IRQHandler
    .long IEL27_IRQHandler
    .long IEL28_IRQHandler
    .long IEL29_IRQHandler
    .long IEL30_IRQHandler
    .long IEL31_IRQHandler
    .long IEL32_IRQHandler
    .long IEL33_IRQHandler
    .long IEL34_IRQHandler
    .long IEL35_IRQHandler
    .long IEL36_IRQHandler
    .long IEL37_IRQHandler
    .long IEL38_IRQHandler
    .long IEL39_IRQHandler
    .long IEL40_IRQHandler
    .long IEL41_IRQHandler
    .long IEL42_IRQHandler
    .long IEL43_IRQHandler
    .long IEL44_IRQHandler
    .long IEL45_IRQHandler
    .long IEL46_IRQHandler
    .long IEL47_IRQHandler
    .long IEL48_IRQHandler
    .long IEL49_IRQHandler
    .long IEL50_IRQHandler
    .long IEL51_IRQHandler
    .long IEL52_IRQHandler
    .long IEL53_IRQHandler
    .long IEL54_IRQHandler
    .long IEL55_IRQHandler
    .long IEL56_IRQHandler
    .long IEL57_IRQHandler
    .long IEL58_IRQHandler
    .long IEL59_IRQHandler
    .long IEL60_IRQHandler
    .long IEL61_IRQHandler
    .long IEL62_IRQHandler
    .long IEL63_IRQHandler
    .long IEL64_IRQHandler
    .long IEL65_IRQHandler
    .long IEL66_IRQHandler
    .long IEL67_IRQHandler
    .long IEL68_IRQHandler
    .long IEL69_IRQHandler
    .long IEL70_IRQHandler
    .long IEL71_IRQHandler
    .long IEL72_IRQHandler
    .long IEL73_IRQHandler
    .long IEL74_IRQHandler
    .long IEL75_IRQHandler
    .long IEL76_IRQHandler
    .long IEL77_IRQHandler
    .long IEL78_IRQHandler
    .long IEL79_IRQHandler
    .long IEL80_IRQHandler
    .long IEL81_IRQHandler
    .long IEL82_IRQHandler
    .long IEL83_IRQHandler
    .long IEL84_IRQHandler
    .long IEL85_IRQHandler
    .long IEL86_IRQHandler
    .long IEL87_IRQHandler
    .long IEL88_IRQHandler
    .long IEL89_IRQHandler
    .long IEL90_IRQHandler
    .long IEL91_IRQHandler
    .long IEL92_IRQHandler
    .long IEL93_IRQHandler
    .long IEL94_IRQHandler
    .long IEL95_IRQHandler

    // Define default implementations for interrupts, redirecting to
    // Default_Handler when not implemented.
    IRQ NMI_Handler
    IRQ HardFault_Handler
    IRQ MemoryManagement_Handler
    IRQ BusFault_Handler
    IRQ UsageFault_Handler
    IRQ SVC_Handler
    IRQ DebugMon_Handler
    IRQ PendSV_Handler
    IRQ SysTick_Handler
    IRQ IEL0_IRQHandler
    IRQ IEL1_IRQHandler
    IRQ IEL2_IRQHandler
    IRQ IEL3_IRQHandler
    IRQ IEL4_IRQHandler
    IRQ IEL5_IRQHandler
    IRQ IEL6_IRQHandler
    IRQ IEL7_IRQHandler
    IRQ IEL8_IRQHandler
    IRQ IEL9_IRQHandler
    IRQ IEL10_IRQHandler
    IRQ IEL11_IRQHandler
    IRQ IEL12_IRQHandler
    IRQ IEL13_IRQHandler
    IRQ IEL14_IRQHandler
    IRQ IEL15_IRQHandler
    IRQ IEL16_IRQHandler
    IRQ IEL17_IRQHandler
    IRQ IEL18_IRQHandler
    IRQ IEL19_IRQHandler
    IRQ IEL20_IRQHandler
    IRQ IEL21_IRQHandler
    IRQ IEL22_IRQHandler
    IRQ IEL23_IRQHandler
    IRQ IEL24_IRQHandler
    IRQ IEL25_IRQHandler
    IRQ IEL26_IRQHandler
    IRQ IEL27_IRQHandler
    IRQ IEL28_IRQHandler
    IRQ IEL29_IRQHandler
    IRQ IEL30_IRQHandler
    IRQ IEL31_IRQHandler
    IRQ IEL32_IRQHandler
    IRQ IEL33_IRQHandler
    IRQ IEL34_IRQHandler
    IRQ IEL35_IRQHandler
    IRQ IEL36_IRQHandler
    IRQ IEL37_IRQHandler
    IRQ IEL38_IRQHandler
    IRQ IEL39_IRQHandler
    IRQ IEL40_IRQHandler
    IRQ IEL41_IRQHandler
    IRQ IEL42_IRQHandler
    IRQ IEL43_IRQHandler
    IRQ IEL44_IRQHandler
    IRQ IEL45_IRQHandler
    IRQ IEL46_IRQHandler
    IRQ IEL47_IRQHandler
    IRQ IEL48_IRQHandler
    IRQ IEL49_IRQHandler
    IRQ IEL50_IRQHandler
    IRQ IEL51_IRQHandler
    IRQ IEL52_IRQHandler
    IRQ IEL53_IRQHandler
    IRQ IEL54_IRQHandler
    IRQ IEL55_IRQHandler
    IRQ IEL56_IRQHandler
    IRQ IEL57_IRQHandler
    IRQ IEL58_IRQHandler
    IRQ IEL59_IRQHandler
    IRQ IEL60_IRQHandler
    IRQ IEL61_IRQHandler
    IRQ IEL62_IRQHandler
    IRQ IEL63_IRQHandler
    IRQ IEL64_IRQHandler
    IRQ IEL65_IRQHandler
    IRQ IEL66_IRQHandler
    IRQ IEL67_IRQHandler
    IRQ IEL68_IRQHandler
    IRQ IEL69_IRQHandler
    IRQ IEL70_IRQHandler
    IRQ IEL71_IRQHandler
    IRQ IEL72_IRQHandler
    IRQ IEL73_IRQHandler
    IRQ IEL74_IRQHandler
    IRQ IEL75_IRQHandler
    IRQ IEL76_IRQHandler
    IRQ IEL77_IRQHandler
    IRQ IEL78_IRQHandler
    IRQ IEL79_IRQHandler
    IRQ IEL80_IRQHandler
    IRQ IEL81_IRQHandler
    IRQ IEL82_IRQHandler
    IRQ IEL83_IRQHandler
    IRQ IEL84_IRQHandler
    IRQ IEL85_IRQHandler
    IRQ IEL86_IRQHandler
    IRQ IEL87_IRQHandler
    IRQ IEL88_IRQHandler
    IRQ IEL89_IRQHandler
    IRQ IEL90_IRQHandler
    IRQ IEL91_IRQHandler
    IRQ IEL92_IRQHandler
    IRQ IEL93_IRQHandler
    IRQ IEL94_IRQHandler
    IRQ IEL95_IRQHandler

.size __isr_vector, .-__isr_vector
